##  Use Application Rationalization Dashboard
The pre-defined dashboard shows you at a glance how your application rationalization is progressing. Keep in mind that KPIs are calculated once a day, so the progress will only show the next day.
![Application rationalization dashboard showing KPIs for cost, TIME assessment, and data quality](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loiod93847bd734c4b90af549fe9f70180e1_HiRes.png)
